package pb

type ChatMessages struct {
	Id        int64  `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	SessionId int64  `protobuf:"varint,2,opt,name=sessionId,proto3" json:"sessionId,omitempty"`
	SenderId  int64  `protobuf:"varint,3,opt,name=senderId,proto3" json:"senderId,omitempty"`
	Type      string `protobuf:"bytes,4,opt,name=type,proto3" json:"type,omitempty"`
	Content   string `protobuf:"bytes,5,opt,name=content,proto3" json:"content,omitempty"`
	CreatedAt int64  `protobuf:"varint,6,opt,name=createdAt,proto3" json:"createdAt,omitempty"`
}

func (x *ChatMessages) GetId() int64 {
	if x != nil {
		return x.Id
	}
	return 0
}

func (x *ChatMessages) GetSessionId() int64 {
	if x != nil {
		return x.SessionId
	}
	return 0
}

func (x *ChatMessages) GetSenderId() int64 {
	if x != nil {
		return x.SenderId
	}
	return 0
}

func (x *ChatMessages) GetType() string {
	if x != nil {
		return x.Type
	}
	return ""
}

func (x *ChatMessages) GetContent() string {
	if x != nil {
		return x.Content
	}
	return ""
}

func (x *ChatMessages) GetCreatedAt() int64 {
	if x != nil {
		return x.CreatedAt
	}
	return 0
}

type AddChatMessagesReq struct {
	SessionId int64  `protobuf:"varint,1,opt,name=sessionId,proto3" json:"sessionId,omitempty"`
	SenderId  int64  `protobuf:"varint,2,opt,name=senderId,proto3" json:"senderId,omitempty"`
	Type      string `protobuf:"bytes,3,opt,name=type,proto3" json:"type,omitempty"`
	Content   string `protobuf:"bytes,4,opt,name=content,proto3" json:"content,omitempty"`
}

func (x *AddChatMessagesReq) GetSessionId() int64 {
	if x != nil {
		return x.SessionId
	}
	return 0
}

func (x *AddChatMessagesReq) GetSenderId() int64 {
	if x != nil {
		return x.SenderId
	}
	return 0
}

func (x *AddChatMessagesReq) GetType() string {
	if x != nil {
		return x.Type
	}
	return ""
}

func (x *AddChatMessagesReq) GetContent() string {
	if x != nil {
		return x.Content
	}
	return ""
}

type AddChatMessagesResp struct {
	Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
}

func (x *AddChatMessagesResp) GetId() int64 {
	if x != nil {
		return x.Id
	}
	return 0
}

type DelChatMessagesReq struct {
	Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
}

func (x *DelChatMessagesReq) GetId() int64 {
	if x != nil {
		return x.Id
	}
	return 0
}

type DelChatMessagesResp struct{}

type GetChatMessagesByIdReq struct {
	Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
}

func (x *GetChatMessagesByIdReq) GetId() int64 {
	if x != nil {
		return x.Id
	}
	return 0
}

type GetChatMessagesByIdResp struct {
	ChatMessages *ChatMessages `protobuf:"bytes,1,opt,name=chatMessages,proto3" json:"chatMessages,omitempty"`
}

func (x *GetChatMessagesByIdResp) GetChatMessages() *ChatMessages {
	if x != nil {
		return x.ChatMessages
	}
	return nil
}

type SearchChatMessagesReq struct {
	Page      int64  `protobuf:"varint,1,opt,name=page,proto3" json:"page,omitempty"`
	Limit     int64  `protobuf:"varint,2,opt,name=limit,proto3" json:"limit,omitempty"`
	SessionId int64  `protobuf:"varint,3,opt,name=sessionId,proto3" json:"sessionId,omitempty"`
	SenderId  *int64 `protobuf:"varint,4,opt,name=senderId,proto3,oneof" json:"senderId,omitempty"`
}

func (x *SearchChatMessagesReq) GetPage() int64 {
	if x != nil {
		return x.Page
	}
	return 0
}

func (x *SearchChatMessagesReq) GetLimit() int64 {
	if x != nil {
		return x.Limit
	}
	return 0
}

func (x *SearchChatMessagesReq) GetSessionId() int64 {
	if x != nil {
		return x.SessionId
	}
	return 0
}

func (x *SearchChatMessagesReq) GetSenderId() *int64 {
	if x != nil {
		return x.SenderId
	}
	return nil
}

type SearchChatMessagesResp struct {
	ChatMessages []*ChatMessages `protobuf:"bytes,1,rep,name=chatMessages,proto3" json:"chatMessages,omitempty"`
}

func (x *SearchChatMessagesResp) GetChatMessages() []*ChatMessages {
	if x != nil {
		return x.ChatMessages
	}
	return nil
}
